# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: grafeas/grafeas_v1/proto/provenance.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
    name="grafeas/grafeas_v1/proto/provenance.proto",
    package="grafeas.v1",
    syntax="proto3",
    serialized_options=b"\n\rio.grafeas.v1P\001ZFgoogle.golang.org/genproto/googleapis/grafeas/grafeas_v1/proto;grafeas\242\002\003GRA",
    create_key=_descriptor._internal_create_key,
    serialized_pb=b'\n)grafeas/grafeas_v1/proto/provenance.proto\x12\ngrafeas.v1\x1a\x1fgoogle/protobuf/timestamp.proto"\x90\x04\n\x0f\x42uildProvenance\x12\n\n\x02id\x18\x01 \x01(\t\x12\x12\n\nproject_id\x18\x02 \x01(\t\x12%\n\x08\x63ommands\x18\x03 \x03(\x0b\x32\x13.grafeas.v1.Command\x12-\n\x0f\x62uilt_artifacts\x18\x04 \x03(\x0b\x32\x14.grafeas.v1.Artifact\x12/\n\x0b\x63reate_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nstart_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_time\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07\x63reator\x18\x08 \x01(\t\x12\x10\n\x08logs_uri\x18\t \x01(\t\x12-\n\x11source_provenance\x18\n \x01(\x0b\x32\x12.grafeas.v1.Source\x12\x12\n\ntrigger_id\x18\x0b \x01(\t\x12\x44\n\rbuild_options\x18\x0c \x03(\x0b\x32-.grafeas.v1.BuildProvenance.BuildOptionsEntry\x12\x17\n\x0f\x62uilder_version\x18\r \x01(\t\x1a\x33\n\x11\x42uildOptionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01"\x95\x02\n\x06Source\x12#\n\x1b\x61rtifact_storage_source_uri\x18\x01 \x01(\t\x12\x37\n\x0b\x66ile_hashes\x18\x02 \x03(\x0b\x32".grafeas.v1.Source.FileHashesEntry\x12*\n\x07\x63ontext\x18\x03 \x01(\x0b\x32\x19.grafeas.v1.SourceContext\x12\x36\n\x13\x61\x64\x64itional_contexts\x18\x04 \x03(\x0b\x32\x19.grafeas.v1.SourceContext\x1aI\n\x0f\x46ileHashesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12%\n\x05value\x18\x02 \x01(\x0b\x32\x16.grafeas.v1.FileHashes:\x02\x38\x01"1\n\nFileHashes\x12#\n\tfile_hash\x18\x01 \x03(\x0b\x32\x10.grafeas.v1.Hash"#\n\x04Hash\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c"]\n\x07\x43ommand\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0b\n\x03\x65nv\x18\x02 \x03(\t\x12\x0c\n\x04\x61rgs\x18\x03 \x03(\t\x12\x0b\n\x03\x64ir\x18\x04 \x01(\t\x12\n\n\x02id\x18\x05 \x01(\t\x12\x10\n\x08wait_for\x18\x06 \x03(\t"7\n\x08\x41rtifact\x12\x10\n\x08\x63hecksum\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\r\n\x05names\x18\x03 \x03(\t"\x9a\x02\n\rSourceContext\x12\x38\n\ncloud_repo\x18\x01 \x01(\x0b\x32".grafeas.v1.CloudRepoSourceContextH\x00\x12\x31\n\x06gerrit\x18\x02 \x01(\x0b\x32\x1f.grafeas.v1.GerritSourceContextH\x00\x12+\n\x03git\x18\x03 \x01(\x0b\x32\x1c.grafeas.v1.GitSourceContextH\x00\x12\x35\n\x06labels\x18\x04 \x03(\x0b\x32%.grafeas.v1.SourceContext.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\t\n\x07\x63ontext"\x8a\x01\n\x0c\x41liasContext\x12+\n\x04kind\x18\x01 \x01(\x0e\x32\x1d.grafeas.v1.AliasContext.Kind\x12\x0c\n\x04name\x18\x02 \x01(\t"?\n\x04Kind\x12\x14\n\x10KIND_UNSPECIFIED\x10\x00\x12\t\n\x05\x46IXED\x10\x01\x12\x0b\n\x07MOVABLE\x10\x02\x12\t\n\x05OTHER\x10\x04"\x93\x01\n\x16\x43loudRepoSourceContext\x12#\n\x07repo_id\x18\x01 \x01(\x0b\x32\x12.grafeas.v1.RepoId\x12\x15\n\x0brevision_id\x18\x02 \x01(\tH\x00\x12\x31\n\ralias_context\x18\x03 \x01(\x0b\x32\x18.grafeas.v1.AliasContextH\x00\x42\n\n\x08revision"\x95\x01\n\x13GerritSourceContext\x12\x10\n\x08host_uri\x18\x01 \x01(\t\x12\x16\n\x0egerrit_project\x18\x02 \x01(\t\x12\x15\n\x0brevision_id\x18\x03 \x01(\tH\x00\x12\x31\n\ralias_context\x18\x04 \x01(\x0b\x32\x18.grafeas.v1.AliasContextH\x00\x42\n\n\x08revision"4\n\x10GitSourceContext\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\x13\n\x0brevision_id\x18\x02 \x01(\t"S\n\x06RepoId\x12\x34\n\x0fproject_repo_id\x18\x01 \x01(\x0b\x32\x19.grafeas.v1.ProjectRepoIdH\x00\x12\r\n\x03uid\x18\x02 \x01(\tH\x00\x42\x04\n\x02id"6\n\rProjectRepoId\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x11\n\trepo_name\x18\x02 \x01(\tB_\n\rio.grafeas.v1P\x01ZFgoogle.golang.org/genproto/googleapis/grafeas/grafeas_v1/proto;grafeas\xa2\x02\x03GRAb\x06proto3',
    dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,],
)


_ALIASCONTEXT_KIND = _descriptor.EnumDescriptor(
    name="Kind",
    full_name="grafeas.v1.AliasContext.Kind",
    filename=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
    values=[
        _descriptor.EnumValueDescriptor(
            name="KIND_UNSPECIFIED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="FIXED",
            index=1,
            number=1,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="MOVABLE",
            index=2,
            number=2,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="OTHER",
            index=3,
            number=4,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=1502,
    serialized_end=1565,
)
_sym_db.RegisterEnumDescriptor(_ALIASCONTEXT_KIND)


_BUILDPROVENANCE_BUILDOPTIONSENTRY = _descriptor.Descriptor(
    name="BuildOptionsEntry",
    full_name="grafeas.v1.BuildProvenance.BuildOptionsEntry",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="key",
            full_name="grafeas.v1.BuildProvenance.BuildOptionsEntry.key",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="value",
            full_name="grafeas.v1.BuildProvenance.BuildOptionsEntry.value",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=b"8\001",
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=568,
    serialized_end=619,
)

_BUILDPROVENANCE = _descriptor.Descriptor(
    name="BuildProvenance",
    full_name="grafeas.v1.BuildProvenance",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="id",
            full_name="grafeas.v1.BuildProvenance.id",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="project_id",
            full_name="grafeas.v1.BuildProvenance.project_id",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="commands",
            full_name="grafeas.v1.BuildProvenance.commands",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="built_artifacts",
            full_name="grafeas.v1.BuildProvenance.built_artifacts",
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="create_time",
            full_name="grafeas.v1.BuildProvenance.create_time",
            index=4,
            number=5,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="start_time",
            full_name="grafeas.v1.BuildProvenance.start_time",
            index=5,
            number=6,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="end_time",
            full_name="grafeas.v1.BuildProvenance.end_time",
            index=6,
            number=7,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="creator",
            full_name="grafeas.v1.BuildProvenance.creator",
            index=7,
            number=8,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="logs_uri",
            full_name="grafeas.v1.BuildProvenance.logs_uri",
            index=8,
            number=9,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="source_provenance",
            full_name="grafeas.v1.BuildProvenance.source_provenance",
            index=9,
            number=10,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="trigger_id",
            full_name="grafeas.v1.BuildProvenance.trigger_id",
            index=10,
            number=11,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="build_options",
            full_name="grafeas.v1.BuildProvenance.build_options",
            index=11,
            number=12,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="builder_version",
            full_name="grafeas.v1.BuildProvenance.builder_version",
            index=12,
            number=13,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[_BUILDPROVENANCE_BUILDOPTIONSENTRY,],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=91,
    serialized_end=619,
)


_SOURCE_FILEHASHESENTRY = _descriptor.Descriptor(
    name="FileHashesEntry",
    full_name="grafeas.v1.Source.FileHashesEntry",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="key",
            full_name="grafeas.v1.Source.FileHashesEntry.key",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="value",
            full_name="grafeas.v1.Source.FileHashesEntry.value",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=b"8\001",
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=826,
    serialized_end=899,
)

_SOURCE = _descriptor.Descriptor(
    name="Source",
    full_name="grafeas.v1.Source",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="artifact_storage_source_uri",
            full_name="grafeas.v1.Source.artifact_storage_source_uri",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="file_hashes",
            full_name="grafeas.v1.Source.file_hashes",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="context",
            full_name="grafeas.v1.Source.context",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="additional_contexts",
            full_name="grafeas.v1.Source.additional_contexts",
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[_SOURCE_FILEHASHESENTRY,],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=622,
    serialized_end=899,
)


_FILEHASHES = _descriptor.Descriptor(
    name="FileHashes",
    full_name="grafeas.v1.FileHashes",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="file_hash",
            full_name="grafeas.v1.FileHashes.file_hash",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=901,
    serialized_end=950,
)


_HASH = _descriptor.Descriptor(
    name="Hash",
    full_name="grafeas.v1.Hash",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="type",
            full_name="grafeas.v1.Hash.type",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="value",
            full_name="grafeas.v1.Hash.value",
            index=1,
            number=2,
            type=12,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"",
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=952,
    serialized_end=987,
)


_COMMAND = _descriptor.Descriptor(
    name="Command",
    full_name="grafeas.v1.Command",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="grafeas.v1.Command.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="env",
            full_name="grafeas.v1.Command.env",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="args",
            full_name="grafeas.v1.Command.args",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="dir",
            full_name="grafeas.v1.Command.dir",
            index=3,
            number=4,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="id",
            full_name="grafeas.v1.Command.id",
            index=4,
            number=5,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="wait_for",
            full_name="grafeas.v1.Command.wait_for",
            index=5,
            number=6,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=989,
    serialized_end=1082,
)


_ARTIFACT = _descriptor.Descriptor(
    name="Artifact",
    full_name="grafeas.v1.Artifact",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="checksum",
            full_name="grafeas.v1.Artifact.checksum",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="id",
            full_name="grafeas.v1.Artifact.id",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="names",
            full_name="grafeas.v1.Artifact.names",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1084,
    serialized_end=1139,
)


_SOURCECONTEXT_LABELSENTRY = _descriptor.Descriptor(
    name="LabelsEntry",
    full_name="grafeas.v1.SourceContext.LabelsEntry",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="key",
            full_name="grafeas.v1.SourceContext.LabelsEntry.key",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="value",
            full_name="grafeas.v1.SourceContext.LabelsEntry.value",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=b"8\001",
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1368,
    serialized_end=1413,
)

_SOURCECONTEXT = _descriptor.Descriptor(
    name="SourceContext",
    full_name="grafeas.v1.SourceContext",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="cloud_repo",
            full_name="grafeas.v1.SourceContext.cloud_repo",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="gerrit",
            full_name="grafeas.v1.SourceContext.gerrit",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="git",
            full_name="grafeas.v1.SourceContext.git",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="labels",
            full_name="grafeas.v1.SourceContext.labels",
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[_SOURCECONTEXT_LABELSENTRY,],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name="context",
            full_name="grafeas.v1.SourceContext.context",
            index=0,
            containing_type=None,
            create_key=_descriptor._internal_create_key,
            fields=[],
        ),
    ],
    serialized_start=1142,
    serialized_end=1424,
)


_ALIASCONTEXT = _descriptor.Descriptor(
    name="AliasContext",
    full_name="grafeas.v1.AliasContext",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="kind",
            full_name="grafeas.v1.AliasContext.kind",
            index=0,
            number=1,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="name",
            full_name="grafeas.v1.AliasContext.name",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[_ALIASCONTEXT_KIND,],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1427,
    serialized_end=1565,
)


_CLOUDREPOSOURCECONTEXT = _descriptor.Descriptor(
    name="CloudRepoSourceContext",
    full_name="grafeas.v1.CloudRepoSourceContext",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="repo_id",
            full_name="grafeas.v1.CloudRepoSourceContext.repo_id",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="revision_id",
            full_name="grafeas.v1.CloudRepoSourceContext.revision_id",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="alias_context",
            full_name="grafeas.v1.CloudRepoSourceContext.alias_context",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name="revision",
            full_name="grafeas.v1.CloudRepoSourceContext.revision",
            index=0,
            containing_type=None,
            create_key=_descriptor._internal_create_key,
            fields=[],
        ),
    ],
    serialized_start=1568,
    serialized_end=1715,
)


_GERRITSOURCECONTEXT = _descriptor.Descriptor(
    name="GerritSourceContext",
    full_name="grafeas.v1.GerritSourceContext",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="host_uri",
            full_name="grafeas.v1.GerritSourceContext.host_uri",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="gerrit_project",
            full_name="grafeas.v1.GerritSourceContext.gerrit_project",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="revision_id",
            full_name="grafeas.v1.GerritSourceContext.revision_id",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="alias_context",
            full_name="grafeas.v1.GerritSourceContext.alias_context",
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name="revision",
            full_name="grafeas.v1.GerritSourceContext.revision",
            index=0,
            containing_type=None,
            create_key=_descriptor._internal_create_key,
            fields=[],
        ),
    ],
    serialized_start=1718,
    serialized_end=1867,
)


_GITSOURCECONTEXT = _descriptor.Descriptor(
    name="GitSourceContext",
    full_name="grafeas.v1.GitSourceContext",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="url",
            full_name="grafeas.v1.GitSourceContext.url",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="revision_id",
            full_name="grafeas.v1.GitSourceContext.revision_id",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1869,
    serialized_end=1921,
)


_REPOID = _descriptor.Descriptor(
    name="RepoId",
    full_name="grafeas.v1.RepoId",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="project_repo_id",
            full_name="grafeas.v1.RepoId.project_repo_id",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="uid",
            full_name="grafeas.v1.RepoId.uid",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name="id",
            full_name="grafeas.v1.RepoId.id",
            index=0,
            containing_type=None,
            create_key=_descriptor._internal_create_key,
            fields=[],
        ),
    ],
    serialized_start=1923,
    serialized_end=2006,
)


_PROJECTREPOID = _descriptor.Descriptor(
    name="ProjectRepoId",
    full_name="grafeas.v1.ProjectRepoId",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="project_id",
            full_name="grafeas.v1.ProjectRepoId.project_id",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="repo_name",
            full_name="grafeas.v1.ProjectRepoId.repo_name",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2008,
    serialized_end=2062,
)

_BUILDPROVENANCE_BUILDOPTIONSENTRY.containing_type = _BUILDPROVENANCE
_BUILDPROVENANCE.fields_by_name["commands"].message_type = _COMMAND
_BUILDPROVENANCE.fields_by_name["built_artifacts"].message_type = _ARTIFACT
_BUILDPROVENANCE.fields_by_name[
    "create_time"
].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_BUILDPROVENANCE.fields_by_name[
    "start_time"
].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_BUILDPROVENANCE.fields_by_name[
    "end_time"
].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_BUILDPROVENANCE.fields_by_name["source_provenance"].message_type = _SOURCE
_BUILDPROVENANCE.fields_by_name[
    "build_options"
].message_type = _BUILDPROVENANCE_BUILDOPTIONSENTRY
_SOURCE_FILEHASHESENTRY.fields_by_name["value"].message_type = _FILEHASHES
_SOURCE_FILEHASHESENTRY.containing_type = _SOURCE
_SOURCE.fields_by_name["file_hashes"].message_type = _SOURCE_FILEHASHESENTRY
_SOURCE.fields_by_name["context"].message_type = _SOURCECONTEXT
_SOURCE.fields_by_name["additional_contexts"].message_type = _SOURCECONTEXT
_FILEHASHES.fields_by_name["file_hash"].message_type = _HASH
_SOURCECONTEXT_LABELSENTRY.containing_type = _SOURCECONTEXT
_SOURCECONTEXT.fields_by_name["cloud_repo"].message_type = _CLOUDREPOSOURCECONTEXT
_SOURCECONTEXT.fields_by_name["gerrit"].message_type = _GERRITSOURCECONTEXT
_SOURCECONTEXT.fields_by_name["git"].message_type = _GITSOURCECONTEXT
_SOURCECONTEXT.fields_by_name["labels"].message_type = _SOURCECONTEXT_LABELSENTRY
_SOURCECONTEXT.oneofs_by_name["context"].fields.append(
    _SOURCECONTEXT.fields_by_name["cloud_repo"]
)
_SOURCECONTEXT.fields_by_name[
    "cloud_repo"
].containing_oneof = _SOURCECONTEXT.oneofs_by_name["context"]
_SOURCECONTEXT.oneofs_by_name["context"].fields.append(
    _SOURCECONTEXT.fields_by_name["gerrit"]
)
_SOURCECONTEXT.fields_by_name[
    "gerrit"
].containing_oneof = _SOURCECONTEXT.oneofs_by_name["context"]
_SOURCECONTEXT.oneofs_by_name["context"].fields.append(
    _SOURCECONTEXT.fields_by_name["git"]
)
_SOURCECONTEXT.fields_by_name["git"].containing_oneof = _SOURCECONTEXT.oneofs_by_name[
    "context"
]
_ALIASCONTEXT.fields_by_name["kind"].enum_type = _ALIASCONTEXT_KIND
_ALIASCONTEXT_KIND.containing_type = _ALIASCONTEXT
_CLOUDREPOSOURCECONTEXT.fields_by_name["repo_id"].message_type = _REPOID
_CLOUDREPOSOURCECONTEXT.fields_by_name["alias_context"].message_type = _ALIASCONTEXT
_CLOUDREPOSOURCECONTEXT.oneofs_by_name["revision"].fields.append(
    _CLOUDREPOSOURCECONTEXT.fields_by_name["revision_id"]
)
_CLOUDREPOSOURCECONTEXT.fields_by_name[
    "revision_id"
].containing_oneof = _CLOUDREPOSOURCECONTEXT.oneofs_by_name["revision"]
_CLOUDREPOSOURCECONTEXT.oneofs_by_name["revision"].fields.append(
    _CLOUDREPOSOURCECONTEXT.fields_by_name["alias_context"]
)
_CLOUDREPOSOURCECONTEXT.fields_by_name[
    "alias_context"
].containing_oneof = _CLOUDREPOSOURCECONTEXT.oneofs_by_name["revision"]
_GERRITSOURCECONTEXT.fields_by_name["alias_context"].message_type = _ALIASCONTEXT
_GERRITSOURCECONTEXT.oneofs_by_name["revision"].fields.append(
    _GERRITSOURCECONTEXT.fields_by_name["revision_id"]
)
_GERRITSOURCECONTEXT.fields_by_name[
    "revision_id"
].containing_oneof = _GERRITSOURCECONTEXT.oneofs_by_name["revision"]
_GERRITSOURCECONTEXT.oneofs_by_name["revision"].fields.append(
    _GERRITSOURCECONTEXT.fields_by_name["alias_context"]
)
_GERRITSOURCECONTEXT.fields_by_name[
    "alias_context"
].containing_oneof = _GERRITSOURCECONTEXT.oneofs_by_name["revision"]
_REPOID.fields_by_name["project_repo_id"].message_type = _PROJECTREPOID
_REPOID.oneofs_by_name["id"].fields.append(_REPOID.fields_by_name["project_repo_id"])
_REPOID.fields_by_name["project_repo_id"].containing_oneof = _REPOID.oneofs_by_name[
    "id"
]
_REPOID.oneofs_by_name["id"].fields.append(_REPOID.fields_by_name["uid"])
_REPOID.fields_by_name["uid"].containing_oneof = _REPOID.oneofs_by_name["id"]
DESCRIPTOR.message_types_by_name["BuildProvenance"] = _BUILDPROVENANCE
DESCRIPTOR.message_types_by_name["Source"] = _SOURCE
DESCRIPTOR.message_types_by_name["FileHashes"] = _FILEHASHES
DESCRIPTOR.message_types_by_name["Hash"] = _HASH
DESCRIPTOR.message_types_by_name["Command"] = _COMMAND
DESCRIPTOR.message_types_by_name["Artifact"] = _ARTIFACT
DESCRIPTOR.message_types_by_name["SourceContext"] = _SOURCECONTEXT
DESCRIPTOR.message_types_by_name["AliasContext"] = _ALIASCONTEXT
DESCRIPTOR.message_types_by_name["CloudRepoSourceContext"] = _CLOUDREPOSOURCECONTEXT
DESCRIPTOR.message_types_by_name["GerritSourceContext"] = _GERRITSOURCECONTEXT
DESCRIPTOR.message_types_by_name["GitSourceContext"] = _GITSOURCECONTEXT
DESCRIPTOR.message_types_by_name["RepoId"] = _REPOID
DESCRIPTOR.message_types_by_name["ProjectRepoId"] = _PROJECTREPOID
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

BuildProvenance = _reflection.GeneratedProtocolMessageType(
    "BuildProvenance",
    (_message.Message,),
    {
        "BuildOptionsEntry": _reflection.GeneratedProtocolMessageType(
            "BuildOptionsEntry",
            (_message.Message,),
            {
                "DESCRIPTOR": _BUILDPROVENANCE_BUILDOPTIONSENTRY,
                "__module__": "grafeas.grafeas_v1.proto.provenance_pb2"
                # @@protoc_insertion_point(class_scope:grafeas.v1.BuildProvenance.BuildOptionsEntry)
            },
        ),
        "DESCRIPTOR": _BUILDPROVENANCE,
        "__module__": "grafeas.grafeas_v1.proto.provenance_pb2",
        "__doc__": """Provenance of a build. Contains all information needed to verify the
  full details about the build from source to completion.
  
  Attributes:
      id:
          Required. Unique identifier of the build.
      project_id:
          ID of the project.
      commands:
          Commands requested by the build.
      built_artifacts:
          Output of the build.
      create_time:
          Time at which the build was created.
      start_time:
          Time at which execution of the build was started.
      end_time:
          Time at which execution of the build was finished.
      creator:
          E-mail address of the user who initiated this build. Note that
          this was the user’s e-mail address at the time the build was
          initiated; this address may not represent the same end-user
          for all time.
      logs_uri:
          URI where any logs for this provenance were written.
      source_provenance:
          Details of the Source input to the build.
      trigger_id:
          Trigger identifier if the build was triggered automatically;
          empty if not.
      build_options:
          Special options applied to this build. This is a catch-all
          field where build providers can enter any desired additional
          details.
      builder_version:
          Version string of the builder at the time this build was
          executed.
  """,
        # @@protoc_insertion_point(class_scope:grafeas.v1.BuildProvenance)
    },
)
_sym_db.RegisterMessage(BuildProvenance)
_sym_db.RegisterMessage(BuildProvenance.BuildOptionsEntry)

Source = _reflection.GeneratedProtocolMessageType(
    "Source",
    (_message.Message,),
    {
        "FileHashesEntry": _reflection.GeneratedProtocolMessageType(
            "FileHashesEntry",
            (_message.Message,),
            {
                "DESCRIPTOR": _SOURCE_FILEHASHESENTRY,
                "__module__": "grafeas.grafeas_v1.proto.provenance_pb2"
                # @@protoc_insertion_point(class_scope:grafeas.v1.Source.FileHashesEntry)
            },
        ),
        "DESCRIPTOR": _SOURCE,
        "__module__": "grafeas.grafeas_v1.proto.provenance_pb2",
        "__doc__": """Source describes the location of the source used for the build.
  
  Attributes:
      artifact_storage_source_uri:
          If provided, the input binary artifacts for the build came
          from this location.
      file_hashes:
          Hash(es) of the build source, which can be used to verify that
          the original source integrity was maintained in the build.
          The keys to this map are file paths used as build source and
          the values contain the hash values for those files.  If the
          build source came in a single package such as a gzipped
          tarfile (.tar.gz), the FileHash will be for the single path to
          that file.
      context:
          If provided, the source code used for the build came from this
          location.
      additional_contexts:
          If provided, some of the source code used for the build may be
          found in these locations, in the case where the source
          repository had multiple remotes or submodules. This list will
          not include the context specified in the context field.
  """,
        # @@protoc_insertion_point(class_scope:grafeas.v1.Source)
    },
)
_sym_db.RegisterMessage(Source)
_sym_db.RegisterMessage(Source.FileHashesEntry)

FileHashes = _reflection.GeneratedProtocolMessageType(
    "FileHashes",
    (_message.Message,),
    {
        "DESCRIPTOR": _FILEHASHES,
        "__module__": "grafeas.grafeas_v1.proto.provenance_pb2",
        "__doc__": """Container message for hashes of byte content of files, used in source
  messages to verify integrity of source input to the build.
  
  Attributes:
      file_hash:
          Required. Collection of file hashes.
  """,
        # @@protoc_insertion_point(class_scope:grafeas.v1.FileHashes)
    },
)
_sym_db.RegisterMessage(FileHashes)

Hash = _reflection.GeneratedProtocolMessageType(
    "Hash",
    (_message.Message,),
    {
        "DESCRIPTOR": _HASH,
        "__module__": "grafeas.grafeas_v1.proto.provenance_pb2",
        "__doc__": """Container message for hash values.
  
  Attributes:
      type:
          Required. The type of hash that was performed, e.g. “SHA-256”.
      value:
          Required. The hash value.
  """,
        # @@protoc_insertion_point(class_scope:grafeas.v1.Hash)
    },
)
_sym_db.RegisterMessage(Hash)

Command = _reflection.GeneratedProtocolMessageType(
    "Command",
    (_message.Message,),
    {
        "DESCRIPTOR": _COMMAND,
        "__module__": "grafeas.grafeas_v1.proto.provenance_pb2",
        "__doc__": """Command describes a step performed as part of the build pipeline.
  
  Attributes:
      name:
          Required. Name of the command, as presented on the command
          line, or if the command is packaged as a Docker container, as
          presented to ``docker pull``.
      env:
          Environment variables set before running this command.
      args:
          Command-line arguments used when executing this command.
      dir:
          Working directory (relative to project source root) used when
          running this command.
      id:
          Optional unique identifier for this command, used in wait_for
          to reference this command as a dependency.
      wait_for:
          The ID(s) of the command(s) that this command depends on.
  """,
        # @@protoc_insertion_point(class_scope:grafeas.v1.Command)
    },
)
_sym_db.RegisterMessage(Command)

Artifact = _reflection.GeneratedProtocolMessageType(
    "Artifact",
    (_message.Message,),
    {
        "DESCRIPTOR": _ARTIFACT,
        "__module__": "grafeas.grafeas_v1.proto.provenance_pb2",
        "__doc__": """Artifact describes a build product.
  
  Attributes:
      checksum:
          Hash or checksum value of a binary, or Docker Registry 2.0
          digest of a container.
      id:
          Artifact ID, if any; for container images, this will be a URL
          by digest like ``gcr.io/projectID/imagename@sha256:123456``.
      names:
          Related artifact names. This may be the path to a binary or
          jar file, or in the case of a container build, the name used
          to push the container image to Google Container Registry, as
          presented to ``docker push``. Note that a single Artifact ID
          can have multiple names, for example if two tags are applied
          to one image.
  """,
        # @@protoc_insertion_point(class_scope:grafeas.v1.Artifact)
    },
)
_sym_db.RegisterMessage(Artifact)

SourceContext = _reflection.GeneratedProtocolMessageType(
    "SourceContext",
    (_message.Message,),
    {
        "LabelsEntry": _reflection.GeneratedProtocolMessageType(
            "LabelsEntry",
            (_message.Message,),
            {
                "DESCRIPTOR": _SOURCECONTEXT_LABELSENTRY,
                "__module__": "grafeas.grafeas_v1.proto.provenance_pb2"
                # @@protoc_insertion_point(class_scope:grafeas.v1.SourceContext.LabelsEntry)
            },
        ),
        "DESCRIPTOR": _SOURCECONTEXT,
        "__module__": "grafeas.grafeas_v1.proto.provenance_pb2",
        "__doc__": """A SourceContext is a reference to a tree of files. A SourceContext
  together with a path point to a unique revision of a single file or
  directory.
  
  Attributes:
      context:
          A SourceContext can refer any one of the following types of
          repositories.
      cloud_repo:
          A SourceContext referring to a revision in a Google Cloud
          Source Repo.
      gerrit:
          A SourceContext referring to a Gerrit project.
      git:
          A SourceContext referring to any third party Git repo (e.g.,
          GitHub).
      labels:
          Labels with user defined metadata.
  """,
        # @@protoc_insertion_point(class_scope:grafeas.v1.SourceContext)
    },
)
_sym_db.RegisterMessage(SourceContext)
_sym_db.RegisterMessage(SourceContext.LabelsEntry)

AliasContext = _reflection.GeneratedProtocolMessageType(
    "AliasContext",
    (_message.Message,),
    {
        "DESCRIPTOR": _ALIASCONTEXT,
        "__module__": "grafeas.grafeas_v1.proto.provenance_pb2",
        "__doc__": """An alias to a repo revision.
  
  Attributes:
      kind:
          The alias kind.
      name:
          The alias name.
  """,
        # @@protoc_insertion_point(class_scope:grafeas.v1.AliasContext)
    },
)
_sym_db.RegisterMessage(AliasContext)

CloudRepoSourceContext = _reflection.GeneratedProtocolMessageType(
    "CloudRepoSourceContext",
    (_message.Message,),
    {
        "DESCRIPTOR": _CLOUDREPOSOURCECONTEXT,
        "__module__": "grafeas.grafeas_v1.proto.provenance_pb2",
        "__doc__": """A CloudRepoSourceContext denotes a particular revision in a Google
  Cloud Source Repo.
  
  Attributes:
      repo_id:
          The ID of the repo.
      revision:
          A revision in a Cloud Repo can be identified by either its
          revision ID or its alias.
      revision_id:
          A revision ID.
      alias_context:
          An alias, which may be a branch or tag.
  """,
        # @@protoc_insertion_point(class_scope:grafeas.v1.CloudRepoSourceContext)
    },
)
_sym_db.RegisterMessage(CloudRepoSourceContext)

GerritSourceContext = _reflection.GeneratedProtocolMessageType(
    "GerritSourceContext",
    (_message.Message,),
    {
        "DESCRIPTOR": _GERRITSOURCECONTEXT,
        "__module__": "grafeas.grafeas_v1.proto.provenance_pb2",
        "__doc__": """A SourceContext referring to a Gerrit project.
  
  Attributes:
      host_uri:
          The URI of a running Gerrit instance.
      gerrit_project:
          The full project name within the host. Projects may be nested,
          so “project/subproject” is a valid project name. The “repo
          name” is the hostURI/project.
      revision:
          A revision in a Gerrit project can be identified by either its
          revision ID or its alias.
      revision_id:
          A revision (commit) ID.
      alias_context:
          An alias, which may be a branch or tag.
  """,
        # @@protoc_insertion_point(class_scope:grafeas.v1.GerritSourceContext)
    },
)
_sym_db.RegisterMessage(GerritSourceContext)

GitSourceContext = _reflection.GeneratedProtocolMessageType(
    "GitSourceContext",
    (_message.Message,),
    {
        "DESCRIPTOR": _GITSOURCECONTEXT,
        "__module__": "grafeas.grafeas_v1.proto.provenance_pb2",
        "__doc__": """A GitSourceContext denotes a particular revision in a third party Git
  repository (e.g., GitHub).
  
  Attributes:
      url:
          Git repository URL.
      revision_id:
          Git commit hash.
  """,
        # @@protoc_insertion_point(class_scope:grafeas.v1.GitSourceContext)
    },
)
_sym_db.RegisterMessage(GitSourceContext)

RepoId = _reflection.GeneratedProtocolMessageType(
    "RepoId",
    (_message.Message,),
    {
        "DESCRIPTOR": _REPOID,
        "__module__": "grafeas.grafeas_v1.proto.provenance_pb2",
        "__doc__": """A unique identifier for a Cloud Repo.
  
  Attributes:
      id:
          A cloud repo can be identified by either its project ID and
          repository name combination, or its globally unique
          identifier.
      project_repo_id:
          A combination of a project ID and a repo name.
      uid:
          A server-assigned, globally unique identifier.
  """,
        # @@protoc_insertion_point(class_scope:grafeas.v1.RepoId)
    },
)
_sym_db.RegisterMessage(RepoId)

ProjectRepoId = _reflection.GeneratedProtocolMessageType(
    "ProjectRepoId",
    (_message.Message,),
    {
        "DESCRIPTOR": _PROJECTREPOID,
        "__module__": "grafeas.grafeas_v1.proto.provenance_pb2",
        "__doc__": """Selects a repo using a Google Cloud Platform project ID (e.g., winged-
  cargo-31) and a repo name within that project.
  
  Attributes:
      project_id:
          The ID of the project.
      repo_name:
          The name of the repo. Leave empty for the default repo.
  """,
        # @@protoc_insertion_point(class_scope:grafeas.v1.ProjectRepoId)
    },
)
_sym_db.RegisterMessage(ProjectRepoId)


DESCRIPTOR._options = None
_BUILDPROVENANCE_BUILDOPTIONSENTRY._options = None
_SOURCE_FILEHASHESENTRY._options = None
_SOURCECONTEXT_LABELSENTRY._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from grafeas.grafeas_v1.proto import (
    grafeas_pb2 as grafeas_dot_grafeas__v1_dot_proto_dot_grafeas__pb2,
)


class GrafeasStub(object):
    """[Grafeas](https://grafeas.io) API.

  Retrieves analysis results of Cloud components such as Docker container
  images.

  Analysis results are stored as a series of occurrences. An `Occurrence`
  contains information about a specific analysis instance on a resource. An
  occurrence refers to a `Note`. A note contains details describing the
  analysis and is generally stored in a separate project, called a `Provider`.
  Multiple occurrences can refer to the same note.

  For example, an SSL vulnerability could affect multiple images. In this case,
  there would be one note for the vulnerability and an occurrence for each
  image with the vulnerability referring to that note.
  """

    def __init__(self, channel):
        """Constructor.

    Args:
      channel: A grpc.Channel.
    """
        self.GetOccurrence = channel.unary_unary(
            "/grafeas.v1.Grafeas/GetOccurrence",
            request_serializer=grafeas_dot_grafeas__v1_dot_proto_dot_grafeas__pb2.GetOccurrenceRequest.SerializeToString,
            response_deserializer=grafeas_dot_grafeas__v1_dot_proto_dot_grafeas__pb2.Occurrence.FromString,
        )
        self.ListOccurrences = channel.unary_unary(
            "/grafeas.v1.Grafeas/ListOccurrences",
            request_serializer=grafeas_dot_grafeas__v1_dot_proto_dot_grafeas__pb2.ListOccurrencesRequest.SerializeToString,
            response_deserializer=grafeas_dot_grafeas__v1_dot_proto_dot_grafeas__pb2.ListOccurrencesResponse.FromString,
        )
        self.DeleteOccurrence = channel.unary_unary(
            "/grafeas.v1.Grafeas/DeleteOccurrence",
            request_serializer=grafeas_dot_grafeas__v1_dot_proto_dot_grafeas__pb2.DeleteOccurrenceRequest.SerializeToString,
            response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
        )
        self.CreateOccurrence = channel.unary_unary(
            "/grafeas.v1.Grafeas/CreateOccurrence",
            request_serializer=grafeas_dot_grafeas__v1_dot_proto_dot_grafeas__pb2.CreateOccurrenceRequest.SerializeToString,
            response_deserializer=grafeas_dot_grafeas__v1_dot_proto_dot_grafeas__pb2.Occurrence.FromString,
        )
        self.BatchCreateOccurrences = channel.unary_unary(
            "/grafeas.v1.Grafeas/BatchCreateOccurrences",
            request_serializer=grafeas_dot_grafeas__v1_dot_proto_dot_grafeas__pb2.BatchCreateOccurrencesRequest.SerializeToString,
            response_deserializer=grafeas_dot_grafeas__v1_dot_proto_dot_grafeas__pb2.BatchCreateOccurrencesResponse.FromString,
        )
        self.UpdateOccurrence = channel.unary_unary(
            "/grafeas.v1.Grafeas/UpdateOccurrence",
            request_serializer=grafeas_dot_grafeas__v1_dot_proto_dot_grafeas__pb2.UpdateOccurrenceRequest.SerializeToString,
            response_deserializer=grafeas_dot_grafeas__v1_dot_proto_dot_grafeas__pb2.Occurrence.FromString,
        )
        self.GetOccurrenceNote = channel.unary_unary(
            "/grafeas.v1.Grafeas/GetOccurrenceNote",
            request_serializer=grafeas_dot_grafeas__v1_dot_proto_dot_grafeas__pb2.GetOccurrenceNoteRequest.SerializeToString,
            response_deserializer=grafeas_dot_grafeas__v1_dot_proto_dot_grafeas__pb2.Note.FromString,
        )
        self.GetNote = channel.unary_unary(
            "/grafeas.v1.Grafeas/GetNote",
            request_serializer=grafeas_dot_grafeas__v1_dot_proto_dot_grafeas__pb2.GetNoteRequest.SerializeToString,
            response_deserializer=grafeas_dot_grafeas__v1_dot_proto_dot_grafeas__pb2.Note.FromString,
        )
        self.ListNotes = channel.unary_unary(
            "/grafeas.v1.Grafeas/ListNotes",
            request_serializer=grafeas_dot_grafeas__v1_dot_proto_dot_grafeas__pb2.ListNotesRequest.SerializeToString,
            response_deserializer=grafeas_dot_grafeas__v1_dot_proto_dot_grafeas__pb2.ListNotesResponse.FromString,
        )
        self.DeleteNote = channel.unary_unary(
            "/grafeas.v1.Grafeas/DeleteNote",
            request_serializer=grafeas_dot_grafeas__v1_dot_proto_dot_grafeas__pb2.DeleteNoteRequest.SerializeToString,
            response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
        )
        self.CreateNote = channel.unary_unary(
            "/grafeas.v1.Grafeas/CreateNote",
            request_serializer=grafeas_dot_grafeas__v1_dot_proto_dot_grafeas__pb2.CreateNoteRequest.SerializeToString,
            response_deserializer=grafeas_dot_grafeas__v1_dot_proto_dot_grafeas__pb2.Note.FromString,
        )
        self.BatchCreateNotes = channel.unary_unary(
            "/grafeas.v1.Grafeas/BatchCreateNotes",
            request_serializer=grafeas_dot_grafeas__v1_dot_proto_dot_grafeas__pb2.BatchCreateNotesRequest.SerializeToString,
            response_deserializer=grafeas_dot_grafeas__v1_dot_proto_dot_grafeas__pb2.BatchCreateNotesResponse.FromString,
        )
        self.UpdateNote = channel.unary_unary(
            "/grafeas.v1.Grafeas/UpdateNote",
            request_serializer=grafeas_dot_grafeas__v1_dot_proto_dot_grafeas__pb2.UpdateNoteRequest.SerializeToString,
            response_deserializer=grafeas_dot_grafeas__v1_dot_proto_dot_grafeas__pb2.Note.FromString,
        )
        self.ListNoteOccurrences = channel.unary_unary(
            "/grafeas.v1.Grafeas/ListNoteOccurrences",
            request_serializer=grafeas_dot_grafeas__v1_dot_proto_dot_grafeas__pb2.ListNoteOccurrencesRequest.SerializeToString,
            response_deserializer=grafeas_dot_grafeas__v1_dot_proto_dot_grafeas__pb2.ListNoteOccurrencesResponse.FromString,
        )


class GrafeasServicer(object):
    """[Grafeas](https://grafeas.io) API.

  Retrieves analysis results of Cloud components such as Docker container
  images.

  Analysis results are stored as a series of occurrences. An `Occurrence`
  contains information about a specific analysis instance on a resource. An
  occurrence refers to a `Note`. A note contains details describing the
  analysis and is generally stored in a separate project, called a `Provider`.
  Multiple occurrences can refer to the same note.

  For example, an SSL vulnerability could affect multiple images. In this case,
  there would be one note for the vulnerability and an occurrence for each
  image with the vulnerability referring to that note.
  """

    def GetOccurrence(self, request, context):
        """Gets the specified occurrence.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ListOccurrences(self, request, context):
        """Lists occurrences for the specified project.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeleteOccurrence(self, request, context):
        """Deletes the specified occurrence. For example, use this method to delete an
    occurrence when the occurrence is no longer applicable for the given
    resource.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def CreateOccurrence(self, request, context):
        """Creates a new occurrence.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def BatchCreateOccurrences(self, request, context):
        """Creates new occurrences in batch.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def UpdateOccurrence(self, request, context):
        """Updates the specified occurrence.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetOccurrenceNote(self, request, context):
        """Gets the note attached to the specified occurrence. Consumer projects can
    use this method to get a note that belongs to a provider project.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetNote(self, request, context):
        """Gets the specified note.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ListNotes(self, request, context):
        """Lists notes for the specified project.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeleteNote(self, request, context):
        """Deletes the specified note.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def CreateNote(self, request, context):
        """Creates a new note.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def BatchCreateNotes(self, request, context):
        """Creates new notes in batch.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def UpdateNote(self, request, context):
        """Updates the specified note.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ListNoteOccurrences(self, request, context):
        """Lists occurrences referencing the specified note. Provider projects can use
    this method to get all occurrences across consumer projects referencing the
    specified note.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_GrafeasServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "GetOccurrence": grpc.unary_unary_rpc_method_handler(
            servicer.GetOccurrence,
            request_deserializer=grafeas_dot_grafeas__v1_dot_proto_dot_grafeas__pb2.GetOccurrenceRequest.FromString,
            response_serializer=grafeas_dot_grafeas__v1_dot_proto_dot_grafeas__pb2.Occurrence.SerializeToString,
        ),
        "ListOccurrences": grpc.unary_unary_rpc_method_handler(
            servicer.ListOccurrences,
            request_deserializer=grafeas_dot_grafeas__v1_dot_proto_dot_grafeas__pb2.ListOccurrencesRequest.FromString,
            response_serializer=grafeas_dot_grafeas__v1_dot_proto_dot_grafeas__pb2.ListOccurrencesResponse.SerializeToString,
        ),
        "DeleteOccurrence": grpc.unary_unary_rpc_method_handler(
            servicer.DeleteOccurrence,
            request_deserializer=grafeas_dot_grafeas__v1_dot_proto_dot_grafeas__pb2.DeleteOccurrenceRequest.FromString,
            response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
        ),
        "CreateOccurrence": grpc.unary_unary_rpc_method_handler(
            servicer.CreateOccurrence,
            request_deserializer=grafeas_dot_grafeas__v1_dot_proto_dot_grafeas__pb2.CreateOccurrenceRequest.FromString,
            response_serializer=grafeas_dot_grafeas__v1_dot_proto_dot_grafeas__pb2.Occurrence.SerializeToString,
        ),
        "BatchCreateOccurrences": grpc.unary_unary_rpc_method_handler(
            servicer.BatchCreateOccurrences,
            request_deserializer=grafeas_dot_grafeas__v1_dot_proto_dot_grafeas__pb2.BatchCreateOccurrencesRequest.FromString,
            response_serializer=grafeas_dot_grafeas__v1_dot_proto_dot_grafeas__pb2.BatchCreateOccurrencesResponse.SerializeToString,
        ),
        "UpdateOccurrence": grpc.unary_unary_rpc_method_handler(
            servicer.UpdateOccurrence,
            request_deserializer=grafeas_dot_grafeas__v1_dot_proto_dot_grafeas__pb2.UpdateOccurrenceRequest.FromString,
            response_serializer=grafeas_dot_grafeas__v1_dot_proto_dot_grafeas__pb2.Occurrence.SerializeToString,
        ),
        "GetOccurrenceNote": grpc.unary_unary_rpc_method_handler(
            servicer.GetOccurrenceNote,
            request_deserializer=grafeas_dot_grafeas__v1_dot_proto_dot_grafeas__pb2.GetOccurrenceNoteRequest.FromString,
            response_serializer=grafeas_dot_grafeas__v1_dot_proto_dot_grafeas__pb2.Note.SerializeToString,
        ),
        "GetNote": grpc.unary_unary_rpc_method_handler(
            servicer.GetNote,
            request_deserializer=grafeas_dot_grafeas__v1_dot_proto_dot_grafeas__pb2.GetNoteRequest.FromString,
            response_serializer=grafeas_dot_grafeas__v1_dot_proto_dot_grafeas__pb2.Note.SerializeToString,
        ),
        "ListNotes": grpc.unary_unary_rpc_method_handler(
            servicer.ListNotes,
            request_deserializer=grafeas_dot_grafeas__v1_dot_proto_dot_grafeas__pb2.ListNotesRequest.FromString,
            response_serializer=grafeas_dot_grafeas__v1_dot_proto_dot_grafeas__pb2.ListNotesResponse.SerializeToString,
        ),
        "DeleteNote": grpc.unary_unary_rpc_method_handler(
            servicer.DeleteNote,
            request_deserializer=grafeas_dot_grafeas__v1_dot_proto_dot_grafeas__pb2.DeleteNoteRequest.FromString,
            response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
        ),
        "CreateNote": grpc.unary_unary_rpc_method_handler(
            servicer.CreateNote,
            request_deserializer=grafeas_dot_grafeas__v1_dot_proto_dot_grafeas__pb2.CreateNoteRequest.FromString,
            response_serializer=grafeas_dot_grafeas__v1_dot_proto_dot_grafeas__pb2.Note.SerializeToString,
        ),
        "BatchCreateNotes": grpc.unary_unary_rpc_method_handler(
            servicer.BatchCreateNotes,
            request_deserializer=grafeas_dot_grafeas__v1_dot_proto_dot_grafeas__pb2.BatchCreateNotesRequest.FromString,
            response_serializer=grafeas_dot_grafeas__v1_dot_proto_dot_grafeas__pb2.BatchCreateNotesResponse.SerializeToString,
        ),
        "UpdateNote": grpc.unary_unary_rpc_method_handler(
            servicer.UpdateNote,
            request_deserializer=grafeas_dot_grafeas__v1_dot_proto_dot_grafeas__pb2.UpdateNoteRequest.FromString,
            response_serializer=grafeas_dot_grafeas__v1_dot_proto_dot_grafeas__pb2.Note.SerializeToString,
        ),
        "ListNoteOccurrences": grpc.unary_unary_rpc_method_handler(
            servicer.ListNoteOccurrences,
            request_deserializer=grafeas_dot_grafeas__v1_dot_proto_dot_grafeas__pb2.ListNoteOccurrencesRequest.FromString,
            response_serializer=grafeas_dot_grafeas__v1_dot_proto_dot_grafeas__pb2.ListNoteOccurrencesResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "grafeas.v1.Grafeas", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: grafeas/grafeas_v1/proto/cvss.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor.FileDescriptor(
    name="grafeas/grafeas_v1/proto/cvss.proto",
    package="grafeas.v1",
    syntax="proto3",
    serialized_options=b"\n\rio.grafeas.v1P\001ZFgoogle.golang.org/genproto/googleapis/grafeas/grafeas_v1/proto;grafeas\242\002\003GRA",
    create_key=_descriptor._internal_create_key,
    serialized_pb=b'\n#grafeas/grafeas_v1/proto/cvss.proto\x12\ngrafeas.v1"\xc5\t\n\x06\x43VSSv3\x12\x12\n\nbase_score\x18\x01 \x01(\x02\x12\x1c\n\x14\x65xploitability_score\x18\x02 \x01(\x02\x12\x14\n\x0cimpact_score\x18\x03 \x01(\x02\x12\x36\n\rattack_vector\x18\x05 \x01(\x0e\x32\x1f.grafeas.v1.CVSSv3.AttackVector\x12>\n\x11\x61ttack_complexity\x18\x06 \x01(\x0e\x32#.grafeas.v1.CVSSv3.AttackComplexity\x12\x42\n\x13privileges_required\x18\x07 \x01(\x0e\x32%.grafeas.v1.CVSSv3.PrivilegesRequired\x12<\n\x10user_interaction\x18\x08 \x01(\x0e\x32".grafeas.v1.CVSSv3.UserInteraction\x12\'\n\x05scope\x18\t \x01(\x0e\x32\x18.grafeas.v1.CVSSv3.Scope\x12\x39\n\x16\x63onfidentiality_impact\x18\n \x01(\x0e\x32\x19.grafeas.v1.CVSSv3.Impact\x12\x33\n\x10integrity_impact\x18\x0b \x01(\x0e\x32\x19.grafeas.v1.CVSSv3.Impact\x12\x36\n\x13\x61vailability_impact\x18\x0c \x01(\x0e\x32\x19.grafeas.v1.CVSSv3.Impact"\x99\x01\n\x0c\x41ttackVector\x12\x1d\n\x19\x41TTACK_VECTOR_UNSPECIFIED\x10\x00\x12\x19\n\x15\x41TTACK_VECTOR_NETWORK\x10\x01\x12\x1a\n\x16\x41TTACK_VECTOR_ADJACENT\x10\x02\x12\x17\n\x13\x41TTACK_VECTOR_LOCAL\x10\x03\x12\x1a\n\x16\x41TTACK_VECTOR_PHYSICAL\x10\x04"l\n\x10\x41ttackComplexity\x12!\n\x1d\x41TTACK_COMPLEXITY_UNSPECIFIED\x10\x00\x12\x19\n\x15\x41TTACK_COMPLEXITY_LOW\x10\x01\x12\x1a\n\x16\x41TTACK_COMPLEXITY_HIGH\x10\x02"\x92\x01\n\x12PrivilegesRequired\x12#\n\x1fPRIVILEGES_REQUIRED_UNSPECIFIED\x10\x00\x12\x1c\n\x18PRIVILEGES_REQUIRED_NONE\x10\x01\x12\x1b\n\x17PRIVILEGES_REQUIRED_LOW\x10\x02\x12\x1c\n\x18PRIVILEGES_REQUIRED_HIGH\x10\x03"m\n\x0fUserInteraction\x12 \n\x1cUSER_INTERACTION_UNSPECIFIED\x10\x00\x12\x19\n\x15USER_INTERACTION_NONE\x10\x01\x12\x1d\n\x19USER_INTERACTION_REQUIRED\x10\x02"F\n\x05Scope\x12\x15\n\x11SCOPE_UNSPECIFIED\x10\x00\x12\x13\n\x0fSCOPE_UNCHANGED\x10\x01\x12\x11\n\rSCOPE_CHANGED\x10\x02"R\n\x06Impact\x12\x16\n\x12IMPACT_UNSPECIFIED\x10\x00\x12\x0f\n\x0bIMPACT_HIGH\x10\x01\x12\x0e\n\nIMPACT_LOW\x10\x02\x12\x0f\n\x0bIMPACT_NONE\x10\x03\x42_\n\rio.grafeas.v1P\x01ZFgoogle.golang.org/genproto/googleapis/grafeas/grafeas_v1/proto;grafeas\xa2\x02\x03GRAb\x06proto3',
)


_CVSSV3_ATTACKVECTOR = _descriptor.EnumDescriptor(
    name="AttackVector",
    full_name="grafeas.v1.CVSSv3.AttackVector",
    filename=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
    values=[
        _descriptor.EnumValueDescriptor(
            name="ATTACK_VECTOR_UNSPECIFIED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="ATTACK_VECTOR_NETWORK",
            index=1,
            number=1,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="ATTACK_VECTOR_ADJACENT",
            index=2,
            number=2,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="ATTACK_VECTOR_LOCAL",
            index=3,
            number=3,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="ATTACK_VECTOR_PHYSICAL",
            index=4,
            number=4,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=594,
    serialized_end=747,
)
_sym_db.RegisterEnumDescriptor(_CVSSV3_ATTACKVECTOR)

_CVSSV3_ATTACKCOMPLEXITY = _descriptor.EnumDescriptor(
    name="AttackComplexity",
    full_name="grafeas.v1.CVSSv3.AttackComplexity",
    filename=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
    values=[
        _descriptor.EnumValueDescriptor(
            name="ATTACK_COMPLEXITY_UNSPECIFIED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="ATTACK_COMPLEXITY_LOW",
            index=1,
            number=1,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="ATTACK_COMPLEXITY_HIGH",
            index=2,
            number=2,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=749,
    serialized_end=857,
)
_sym_db.RegisterEnumDescriptor(_CVSSV3_ATTACKCOMPLEXITY)

_CVSSV3_PRIVILEGESREQUIRED = _descriptor.EnumDescriptor(
    name="PrivilegesRequired",
    full_name="grafeas.v1.CVSSv3.PrivilegesRequired",
    filename=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
    values=[
        _descriptor.EnumValueDescriptor(
            name="PRIVILEGES_REQUIRED_UNSPECIFIED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="PRIVILEGES_REQUIRED_NONE",
            index=1,
            number=1,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="PRIVILEGES_REQUIRED_LOW",
            index=2,
            number=2,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="PRIVILEGES_REQUIRED_HIGH",
            index=3,
            number=3,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=860,
    serialized_end=1006,
)
_sym_db.RegisterEnumDescriptor(_CVSSV3_PRIVILEGESREQUIRED)

_CVSSV3_USERINTERACTION = _descriptor.EnumDescriptor(
    name="UserInteraction",
    full_name="grafeas.v1.CVSSv3.UserInteraction",
    filename=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
    values=[
        _descriptor.EnumValueDescriptor(
            name="USER_INTERACTION_UNSPECIFIED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="USER_INTERACTION_NONE",
            index=1,
            number=1,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="USER_INTERACTION_REQUIRED",
            index=2,
            number=2,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=1008,
    serialized_end=1117,
)
_sym_db.RegisterEnumDescriptor(_CVSSV3_USERINTERACTION)

_CVSSV3_SCOPE = _descriptor.EnumDescriptor(
    name="Scope",
    full_name="grafeas.v1.CVSSv3.Scope",
    filename=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
    values=[
        _descriptor.EnumValueDescriptor(
            name="SCOPE_UNSPECIFIED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="SCOPE_UNCHANGED",
            index=1,
            number=1,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="SCOPE_CHANGED",
            index=2,
            number=2,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=1119,
    serialized_end=1189,
)
_sym_db.RegisterEnumDescriptor(_CVSSV3_SCOPE)

_CVSSV3_IMPACT = _descriptor.EnumDescriptor(
    name="Impact",
    full_name="grafeas.v1.CVSSv3.Impact",
    filename=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
    values=[
        _descriptor.EnumValueDescriptor(
            name="IMPACT_UNSPECIFIED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="IMPACT_HIGH",
            index=1,
            number=1,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="IMPACT_LOW",
            index=2,
            number=2,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="IMPACT_NONE",
            index=3,
            number=3,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=1191,
    serialized_end=1273,
)
_sym_db.RegisterEnumDescriptor(_CVSSV3_IMPACT)


_CVSSV3 = _descriptor.Descriptor(
    name="CVSSv3",
    full_name="grafeas.v1.CVSSv3",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="base_score",
            full_name="grafeas.v1.CVSSv3.base_score",
            index=0,
            number=1,
            type=2,
            cpp_type=6,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="exploitability_score",
            full_name="grafeas.v1.CVSSv3.exploitability_score",
            index=1,
            number=2,
            type=2,
            cpp_type=6,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="impact_score",
            full_name="grafeas.v1.CVSSv3.impact_score",
            index=2,
            number=3,
            type=2,
            cpp_type=6,
            label=1,
            has_default_value=False,
            default_value=float(0),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="attack_vector",
            full_name="grafeas.v1.CVSSv3.attack_vector",
            index=3,
            number=5,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="attack_complexity",
            full_name="grafeas.v1.CVSSv3.attack_complexity",
            index=4,
            number=6,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="privileges_required",
            full_name="grafeas.v1.CVSSv3.privileges_required",
            index=5,
            number=7,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="user_interaction",
            full_name="grafeas.v1.CVSSv3.user_interaction",
            index=6,
            number=8,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="scope",
            full_name="grafeas.v1.CVSSv3.scope",
            index=7,
            number=9,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="confidentiality_impact",
            full_name="grafeas.v1.CVSSv3.confidentiality_impact",
            index=8,
            number=10,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="integrity_impact",
            full_name="grafeas.v1.CVSSv3.integrity_impact",
            index=9,
            number=11,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="availability_impact",
            full_name="grafeas.v1.CVSSv3.availability_impact",
            index=10,
            number=12,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[
        _CVSSV3_ATTACKVECTOR,
        _CVSSV3_ATTACKCOMPLEXITY,
        _CVSSV3_PRIVILEGESREQUIRED,
        _CVSSV3_USERINTERACTION,
        _CVSSV3_SCOPE,
        _CVSSV3_IMPACT,
    ],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=52,
    serialized_end=1273,
)

_CVSSV3.fields_by_name["attack_vector"].enum_type = _CVSSV3_ATTACKVECTOR
_CVSSV3.fields_by_name["attack_complexity"].enum_type = _CVSSV3_ATTACKCOMPLEXITY
_CVSSV3.fields_by_name["privileges_required"].enum_type = _CVSSV3_PRIVILEGESREQUIRED
_CVSSV3.fields_by_name["user_interaction"].enum_type = _CVSSV3_USERINTERACTION
_CVSSV3.fields_by_name["scope"].enum_type = _CVSSV3_SCOPE
_CVSSV3.fields_by_name["confidentiality_impact"].enum_type = _CVSSV3_IMPACT
_CVSSV3.fields_by_name["integrity_impact"].enum_type = _CVSSV3_IMPACT
_CVSSV3.fields_by_name["availability_impact"].enum_type = _CVSSV3_IMPACT
_CVSSV3_ATTACKVECTOR.containing_type = _CVSSV3
_CVSSV3_ATTACKCOMPLEXITY.containing_type = _CVSSV3
_CVSSV3_PRIVILEGESREQUIRED.containing_type = _CVSSV3
_CVSSV3_USERINTERACTION.containing_type = _CVSSV3
_CVSSV3_SCOPE.containing_type = _CVSSV3
_CVSSV3_IMPACT.containing_type = _CVSSV3
DESCRIPTOR.message_types_by_name["CVSSv3"] = _CVSSV3
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CVSSv3 = _reflection.GeneratedProtocolMessageType(
    "CVSSv3",
    (_message.Message,),
    {
        "DESCRIPTOR": _CVSSV3,
        "__module__": "grafeas.grafeas_v1.proto.cvss_pb2",
        "__doc__": """Common Vulnerability Scoring System version 3. For details, see
  https://www.first.org/cvss/specification-document
  
  Attributes:
      base_score:
          The base score is a function of the base metric scores.
      attack_vector:
          Base Metrics Represents the intrinsic characteristics of a
          vulnerability that are constant over time and across user
          environments.
  """,
        # @@protoc_insertion_point(class_scope:grafeas.v1.CVSSv3)
    },
)
_sym_db.RegisterMessage(CVSSv3)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: grafeas/grafeas_v1/proto/common.proto

from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor.FileDescriptor(
    name="grafeas/grafeas_v1/proto/common.proto",
    package="grafeas.v1",
    syntax="proto3",
    serialized_options=b"\n\rio.grafeas.v1P\001ZFgoogle.golang.org/genproto/googleapis/grafeas/grafeas_v1/proto;grafeas\242\002\003GRA",
    create_key=_descriptor._internal_create_key,
    serialized_pb=b'\n%grafeas/grafeas_v1/proto/common.proto\x12\ngrafeas.v1"(\n\nRelatedUrl\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\r\n\x05label\x18\x02 \x01(\t"5\n\tSignature\x12\x11\n\tsignature\x18\x01 \x01(\x0c\x12\x15\n\rpublic_key_id\x18\x02 \x01(\t*\x98\x01\n\x08NoteKind\x12\x19\n\x15NOTE_KIND_UNSPECIFIED\x10\x00\x12\x11\n\rVULNERABILITY\x10\x01\x12\t\n\x05\x42UILD\x10\x02\x12\t\n\x05IMAGE\x10\x03\x12\x0b\n\x07PACKAGE\x10\x04\x12\x0e\n\nDEPLOYMENT\x10\x05\x12\r\n\tDISCOVERY\x10\x06\x12\x0f\n\x0b\x41TTESTATION\x10\x07\x12\x0b\n\x07UPGRADE\x10\x08\x42_\n\rio.grafeas.v1P\x01ZFgoogle.golang.org/genproto/googleapis/grafeas/grafeas_v1/proto;grafeas\xa2\x02\x03GRAb\x06proto3',
)

_NOTEKIND = _descriptor.EnumDescriptor(
    name="NoteKind",
    full_name="grafeas.v1.NoteKind",
    filename=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
    values=[
        _descriptor.EnumValueDescriptor(
            name="NOTE_KIND_UNSPECIFIED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="VULNERABILITY",
            index=1,
            number=1,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="BUILD",
            index=2,
            number=2,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="IMAGE",
            index=3,
            number=3,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="PACKAGE",
            index=4,
            number=4,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="DEPLOYMENT",
            index=5,
            number=5,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="DISCOVERY",
            index=6,
            number=6,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="ATTESTATION",
            index=7,
            number=7,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="UPGRADE",
            index=8,
            number=8,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=151,
    serialized_end=303,
)
_sym_db.RegisterEnumDescriptor(_NOTEKIND)

NoteKind = enum_type_wrapper.EnumTypeWrapper(_NOTEKIND)
NOTE_KIND_UNSPECIFIED = 0
VULNERABILITY = 1
BUILD = 2
IMAGE = 3
PACKAGE = 4
DEPLOYMENT = 5
DISCOVERY = 6
ATTESTATION = 7
UPGRADE = 8


_RELATEDURL = _descriptor.Descriptor(
    name="RelatedUrl",
    full_name="grafeas.v1.RelatedUrl",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="url",
            full_name="grafeas.v1.RelatedUrl.url",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="label",
            full_name="grafeas.v1.RelatedUrl.label",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=53,
    serialized_end=93,
)


_SIGNATURE = _descriptor.Descriptor(
    name="Signature",
    full_name="grafeas.v1.Signature",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="signature",
            full_name="grafeas.v1.Signature.signature",
            index=0,
            number=1,
            type=12,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"",
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="public_key_id",
            full_name="grafeas.v1.Signature.public_key_id",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=95,
    serialized_end=148,
)

DESCRIPTOR.message_types_by_name["RelatedUrl"] = _RELATEDURL
DESCRIPTOR.message_types_by_name["Signature"] = _SIGNATURE
DESCRIPTOR.enum_types_by_name["NoteKind"] = _NOTEKIND
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RelatedUrl = _reflection.GeneratedProtocolMessageType(
    "RelatedUrl",
    (_message.Message,),
    {
        "DESCRIPTOR": _RELATEDURL,
        "__module__": "grafeas.grafeas_v1.proto.common_pb2",
        "__doc__": """Metadata for any related URL information.
  
  Attributes:
      url:
          Specific URL associated with the resource.
      label:
          Label to describe usage of the URL.
  """,
        # @@protoc_insertion_point(class_scope:grafeas.v1.RelatedUrl)
    },
)
_sym_db.RegisterMessage(RelatedUrl)

Signature = _reflection.GeneratedProtocolMessageType(
    "Signature",
    (_message.Message,),
    {
        "DESCRIPTOR": _SIGNATURE,
        "__module__": "grafeas.grafeas_v1.proto.common_pb2",
        "__doc__": """Verifiers (e.g. Kritis implementations) MUST verify signatures with
  respect to the trust anchors defined in policy (e.g. a Kritis policy).
  Typically this means that the verifier has been configured with a map
  from ``public_key_id`` to public key material (and any required
  parameters, e.g. signing algorithm).  In particular, verification
  implementations MUST NOT treat the signature ``public_key_id`` as
  anything more than a key lookup hint. The ``public_key_id`` DOES NOT
  validate or authenticate a public key; it only provides a mechanism
  for quickly selecting a public key ALREADY CONFIGURED on the verifier
  through a trusted channel. Verification implementations MUST reject
  signatures in any of the following circumstances: \* The
  ``public_key_id`` is not recognized by the verifier. \* The public key
  that ``public_key_id`` refers to does not verify the signature with
  respect to the payload.  The ``signature`` contents SHOULD NOT be
  “attached” (where the payload is included with the serialized
  ``signature`` bytes). Verifiers MUST ignore any “attached” payload and
  only verify signatures with respect to explicitly provided payload
  (e.g. a ``payload`` field on the proto message that holds this
  Signature, or the canonical serialization of the proto message that
  holds this signature).
  
  Attributes:
      signature:
          The content of the signature, an opaque bytestring. The
          payload that this signature verifies MUST be unambiguously
          provided with the Signature during verification. A wrapper
          message might provide the payload explicitly. Alternatively, a
          message might have a canonical serialization that can always
          be unambiguously computed to derive the payload.
      public_key_id:
          The identifier for the public key that verifies this
          signature. \* The ``public_key_id`` is required. \* The
          ``public_key_id`` MUST be an RFC3986 conformant URI. \* When
          possible, the ``public_key_id`` SHOULD be an immutable
          reference, such as a cryptographic digest.  Examples of valid
          ``public_key_id``\ s:  OpenPGP V4 public key fingerprint: \*
          “openpgp4fpr:74FAF3B861BDA0870C7B6DEF607E48D2A663AEEA” See
          https://www.iana.org/assignments/uri-schemes/prov/openpgp4fpr
          for more details on this scheme.  RFC6920 digest-named
          SubjectPublicKeyInfo (digest of the DER serialization): \*
          “ni:///sha-256;cD9o9Cq6LG3jD0iKXqEi_vdjJGecm_iXkbqVoScViaU” \*
          “nih:///sha-256;703f68f42aba2c6de30f488a5ea122fef76324679c9bf8
          9791ba95a1271589a5”
  """,
        # @@protoc_insertion_point(class_scope:grafeas.v1.Signature)
    },
)
_sym_db.RegisterMessage(Signature)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
